<?php
/**
 * Fichier gérant l'installation et désinstallation du plugin Login Hash
 *
 * @plugin     Login Hash
 * @copyright  2019
 * @author     Matthieu Marcillaud
 * @licence    GNU/GPL
 * @package    SPIP\Loginhash\Installation
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Fonction d'installation et de mise à jour du plugin Login Hash.
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @param string $version_cible
 *     Version du schéma de données dans ce plugin (déclaré dans paquet.xml)
 * @return void
**/
function loginhash_upgrade($nom_meta_base_version, $version_cible) {
	$maj = [];
	$maj['create'] = [['loginhash_upgrade_hash_logins']];

	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);
}


/**
 * Simplifier les logins d’auteurs (par email) et fusionner/retrouver les auteurs avec des emails doublonnés
 *
 * - on remplit le champ email s’il est vide avec les login étant des "email",
 * - on hash le champ login si :
 *   - le login = email
 *   - le login est vide
 */
function loginhash_upgrade_hash_logins() {
	# Les emails vides avec login de type email : on remplit l’email
	sql_update('spip_auteurs', ['email' => 'login'], [
		"login != ''",
		"login LIKE '%@%'",
		"email = ''",
	]);
	# Hash du login si login vide ou identique à l’email
	sql_update('spip_auteurs', ['login' => 'md5(concat(id_auteur, rand()))'], [
		"((login = '') OR (login = email))",
	]);
}


/**
 * Fonction de désinstallation du plugin Login Hash.
 *
 * @param string $nom_meta_base_version
 *     Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @return void
**/
function loginhash_vider_tables($nom_meta_base_version) {


	effacer_meta($nom_meta_base_version);
}
